@@ -35,8 +35,12 @@ import pytz
 import random
 import string
 import webbrowser
-def open_web(url)
+def to_upper(text):
+    return text.upper()
+def open_web(url):
     webbrowser.open(url)
+def google_search(text):
+    webbrowser.open(f"https://www.google.com/search?q={text}")
 def get_system_summary():
     try:
         os_info = platform.system() + " " + platform.release()
@@ -65,43 +69,7 @@ def generate_password(length=12, strength="strong"):
         chars = string.ascii_letters + string.digits + string.punctuation
 
     return ''.join(random.choice(chars) for _ in range(length))
-def speech_to_text(timeout=5, phrase_time_limit=10, language="fa-IR"):
-    recognizer = sr.Recognizer()
-    with sr.Microphone() as source:
-        print("🎙️ لطفاً صحبت کنید...")
-        audio = recognizer.listen(source, timeout=timeout, phrase_time_limit=phrase_time_limit)
-        try:
-            text = recognizer.recognize_google(audio, language=language)
-            return text
-        except sr.UnknownValueError:
-            return "❌ گفتار قابل تشخیص نبود"
-        except sr.RequestError:
-            return "⚠️ خطا در اتصال به سرویس گوگل"
-def speak(text, lang="auto"):
-    # تشخیص زبان
-    if lang == "auto":
-        lang = "fa" if any('\u0600' <= ch <= '\u06FF' for ch in text) else "en"
 
-    # بررسی پشتیبانی gTTS
-    supported_langs = gtts_langs.tts_langs()
-    if lang not in supported_langs:
-        fallback = "ar" if lang == "fa" else "en"
-        print(f"[!] زبان '{lang}' توسط gTTS پشتیبانی نمی‌شود. استفاده از جایگزین: '{fallback}'")
-        lang = fallback
-
-    # ساخت فایل با نام جديد
-    downloads = get_downloads_dir()
-    downloads.mkdir(parents=True, exist_ok=True)
-    filename = get_unique_filename(base_name="voice", ext=".mp3", folder=downloads)
-
-    tts = gTTS(text=text, lang=lang)
-    tts.save(str(filename))
-    pygame.mixer.init()
-    pygame.mixer.music.load(str(filename))
-    pygame.mixer.music.set_volume(1.0)
-    pygame.mixer.music.play()
-    while pygame.mixer.music.get_busy():
-        time.sleep(0.1)
 def browser(url):
     webbrowser.open(url)
 def run_app(path):
@@ -118,7 +86,7 @@ def get_file_size(path: str):
 def count_words(text: str):
     return len(text.strip().split())
 def get_day_name(date_str: str):
-    date_obj = datetime.datetime.strptime(date_str, "%Y-%m-%d")
+    date_obj = datetime.datetime.strptimcount_wordse(date_str, "%Y-%m-%d")
     return date_obj.strftime("%A")
 
 def get_downloads_dir():
@@ -282,7 +250,7 @@ def clock(unit):
     else:
         return "Invalid unit"
 __all__ = [
-    "text_to_speech", "randcolor", "rgbcolor", "upload_gif", "search_real_usage", "showcursor","count_words", "get_day_name", "get_system_summary",
-    "save_var", "load_var", "getping", "clock", "mouseX", "mouseY","hidecursor", "speak","shapecursor","run_app", "get_file_size", "generate_password",
-    "key", "click", "getcolor", "rc", "ri", "leftclick", "middleclick", "rightclick", "play_mp3", "system", "copy_text", "browser", "speech_to_text", "speak"
+    "text_to_speech", "randcolor", "rgbcolor", "upload_gif", "search_real_usage", "showcursor","count_words", "get_day_name", "get_system_summary","open_web"
+    "save_var", "load_var", "getping", "clock", "mouseX", "mouseY","hidecursor", "shapecursor","run_app", "get_file_size", "generate_password", "google_search",
+    "key", "click", "getcolor", "rc", "ri", "leftclick", "middleclick", "rightclick", "play_mp3", "system", "copy_text", "browser", "speech_to_text", "speak", "to_upper"
 ]
